@@ -75,12 +75,11 @@ EoF
 
 emit_normal CPP 17 g++-12
 emit_normal CPP 17 g++-11
-emit_normal CPP 17 g++-10
 emit_normal CPP 14
 emit_normal TBB
 
 for DEVICE in CUDA; do
-	for CXX in cuda-g++ g++-11 g++-10 ; do
+	for CXX in cuda-g++ g++-11 ; do
 		for STD in 17 ; do
 			for HOST in CPP TBB ; do
 				emit_cuda ${HOST}/${DEVICE} ${STD} ${CXX}
